@@ -1,21 +1,21 @@
 #include <stdio.h>
 #include <zbar.h>
 
-static void my_handler (zbar_image_t *image,
-                        const void *userdata)
+static void my_handler(zbar_image_t *image, const void *userdata)
 {
     /* extract results */
     const zbar_symbol_t *symbol = zbar_image_first_symbol(image);
-    for(; symbol; symbol = zbar_symbol_next(symbol)) {
-        /* do something useful with results */
-        zbar_symbol_type_t typ = zbar_symbol_get_type(symbol);
-        const char *data = zbar_symbol_get_data(symbol);
-        printf("decoded %s symbol \"%s\"\n",
-               zbar_get_symbol_name(typ), data);
+
+    for (; symbol; symbol = zbar_symbol_next(symbol)) {
+	/* do something useful with results */
+	zbar_symbol_type_t typ = zbar_symbol_get_type(symbol);
+	const char *data       = zbar_symbol_get_data(symbol);
+
+	printf("decoded %s symbol \"%s\"\n", zbar_get_symbol_name(typ), data);
     }
 }
 
-int main (int argc, char **argv)
+int main(int argc, char **argv)
 {
     const char *device = "/dev/video0";
 
@@ -26,8 +26,8 @@ int main (int argc, char **argv)
     zbar_processor_set_config(proc, 0, ZBAR_CFG_ENABLE, 1);
 
     /* initialize the Processor */
-    if(argc > 1)
-        device = argv[1];
+    if (argc > 1)
+	device = argv[1];
     zbar_processor_init(proc, device, 1);
 
     /* setup a callback */
@@ -43,5 +43,5 @@ int main (int argc, char **argv)
     /* clean up */
     zbar_processor_destroy(proc);
 
-    return(0);
+    return (0);
 }
