@@ -6,22 +6,22 @@ using namespace zbar;
 
 class MyHandler : public Image::Handler
 {
-    void image_callback (Image &image)
+    void image_callback(Image &image)
     {
-        for(SymbolIterator symbol = image.symbol_begin();
-            symbol != image.symbol_end();
-            ++symbol)
-            cout << "decoded " << symbol->get_type_name() << " symbol "
-                 << "\"" << symbol->get_data() << "\"" << endl;
+	for (SymbolIterator symbol = image.symbol_begin();
+	     symbol != image.symbol_end(); ++symbol)
+	    cout << "decoded " << symbol->get_type_name() << " symbol "
+		 << "\"" << symbol->get_data() << "\"" << endl;
     }
 };
 
-int main (int argc, char **argv)
+int main(int argc, char **argv)
 {
     // create and initialize a Processor
     const char *device = "/dev/video0";
-    if(argc > 1)
-        device = argv[1];
+
+    if (argc > 1)
+	device = argv[1];
     Processor proc(true, device);
 
     // configure the Processor
@@ -36,10 +36,9 @@ int main (int argc, char **argv)
     proc.set_active();
 
     try {
-        // keep scanning until user provides key/mouse input
-        proc.user_wait();
+	// keep scanning until user provides key/mouse input
+	proc.user_wait();
+    } catch (ClosedError &e) {
     }
-    catch(ClosedError &e) {
-    }
-    return(0);
+    return (0);
 }
