@@ -7,15 +7,13 @@
 
 #import <UIKit/UIKit.h>
 
-@interface ReaderSampleViewController
-    : UIViewController
-    // ADD: delegate protocol
-    < ZBarReaderDelegate >
-{
+@interface ReaderSampleViewController : UIViewController
+					// ADD: delegate protocol
+					<ZBarReaderDelegate> {
     UIImageView *resultImage;
     UITextView *resultText;
 }
 @property (nonatomic, retain) IBOutlet UIImageView *resultImage;
 @property (nonatomic, retain) IBOutlet UITextView *resultText;
-- (IBAction) scanButtonTapped;
+- (IBAction)scanButtonTapped;
 @end
