@@ -23,59 +23,61 @@
 #ifndef _QZBARTHREAD_H_
 #define _QZBARTHREAD_H_
 
-#include <QThread>
-#include <QMutex>
-#include <QWaitCondition>
 #include <QEvent>
-#include <zbar/QZBarImage.h>
-#include <zbar/QZBar.h>
+#include <QMutex>
+#include <QThread>
+#include <QWaitCondition>
 #include <zbar.h>
+#include <zbar/QZBar.h>
+#include <zbar/QZBarImage.h>
 
-#define DEFAULT_WIDTH 640
+#define DEFAULT_WIDTH  640
 #define DEFAULT_HEIGHT 480
 
-namespace zbar {
-
-class QZBarThread
-    : public QThread,
-      public Image::Handler
+namespace zbar
+{
+class QZBarThread : public QThread, public Image::Handler
 {
     Q_OBJECT
 
 public:
-    enum EventType {
-        VideoDevice = QEvent::User,
-        VideoEnabled,
-        ScanImage,
-        ReOpen,
-        Exit = QEvent::MaxUser
+    enum EventType
+    {
+	VideoDevice = QEvent::User,
+	VideoEnabled,
+	ScanImage,
+	ReOpen,
+	Exit = QEvent::MaxUser
     };
 
-    class VideoDeviceEvent : public QEvent {
+    class VideoDeviceEvent : public QEvent
+    {
     public:
-        VideoDeviceEvent (const QString &device)
-            : QEvent((QEvent::Type)VideoDevice),
-              device(device)
-        { }
-        const QString device;
+	VideoDeviceEvent(const QString &device)
+	    : QEvent((QEvent::Type)VideoDevice), device(device)
+	{
+	}
+	const QString device;
     };
 
-    class VideoEnabledEvent : public QEvent {
+    class VideoEnabledEvent : public QEvent
+    {
     public:
-        VideoEnabledEvent (bool enabled)
-            : QEvent((QEvent::Type)VideoEnabled),
-              enabled(enabled)
-        { }
-        bool enabled;
+	VideoEnabledEvent(bool enabled)
+	    : QEvent((QEvent::Type)VideoEnabled), enabled(enabled)
+	{
+	}
+	bool enabled;
     };
 
-    class ScanImageEvent : public QEvent {
+    class ScanImageEvent : public QEvent
+    {
     public:
-        ScanImageEvent (const QImage &image)
-            : QEvent((QEvent::Type)ScanImage),
-              image(image)
-        { }
-        const QImage image;
+	ScanImageEvent(const QImage &image)
+	    : QEvent((QEvent::Type)ScanImage), image(image)
+	{
+	}
+	const QImage image;
     };
 
     QMutex mutex;
@@ -85,7 +87,7 @@ public:
     // (NB could(/should?) be QAbstractEventDispatcher except it doesn't
     //  work as documented!? ):
     // protected by mutex
-    QList<QEvent*> queue;
+    QList<QEvent *> queue;
 
     // shared state:
     // written by processor thread just after opening video or
@@ -104,10 +106,9 @@ public:
     QZBarThread(int verbosity = 0);
 
     int get_controls(int index, char **name = NULL, char **group = NULL,
-                     enum QZBar::ControlType *type = NULL,
-                     int *min = NULL, int *max = NULL,
-                     int *def = NULL, int *step = NULL);
-    QVector< QPair< int , QString > > get_menu(int index);
+		     enum QZBar::ControlType *type = NULL, int *min = NULL,
+		     int *max = NULL, int *def = NULL, int *step = NULL);
+    QVector<QPair<int, QString> > get_menu(int index);
     int set_control(char *name, bool value);
     int set_control(char *name, int value);
     int get_control(char *name, bool *value);
@@ -115,37 +116,36 @@ public:
 
     int set_config(std::string cfgstr)
     {
-        return scanner.set_config(cfgstr);
+	return scanner.set_config(cfgstr);
     }
 
-    int set_config(zbar_symbol_type_t symbology,
-                   zbar_config_t config,
-                   int value)
+    int set_config(zbar_symbol_type_t symbology, zbar_config_t config,
+		   int value)
     {
-        return scanner.set_config(symbology, config, value);
+	return scanner.set_config(symbology, config, value);
     }
 
-    int get_config(zbar_symbol_type_t symbology,
-                   zbar_config_t config,
-                   int &value)
+    int get_config(zbar_symbol_type_t symbology, zbar_config_t config,
+		   int &value)
     {
-        return scanner.get_config(symbology, config, value);
+	return scanner.get_config(symbology, config, value);
     }
 
     void request_size(unsigned width, unsigned height);
 
-    int get_resolution(int index, unsigned &width, unsigned &height, float &max_fps);
+    int get_resolution(int index, unsigned &width, unsigned &height,
+		       float &max_fps);
 
     int request_dbus(bool enabled)
     {
-        return scanner.request_dbus(enabled);
+	return scanner.request_dbus(enabled);
     }
 
-    void pushEvent (QEvent *e)
+    void pushEvent(QEvent *e)
     {
-        QMutexLocker locker(&mutex);
-        queue.append(e);
-        newEvent.wakeOne();
+	QMutexLocker locker(&mutex);
+	queue.append(e);
+	newEvent.wakeOne();
     }
 
 Q_SIGNALS:
@@ -161,13 +161,13 @@ protected:
     void enableVideo(bool enable);
     void processImage(Image &image);
 
-    void clear ()
+    void clear()
     {
-        window.clear();
-        if(image) {
-            delete image;
-            image = NULL;
-        }
+	window.clear();
+	if (image) {
+	    delete image;
+	    image = NULL;
+	}
     }
 
     virtual void image_callback(Image &image);
@@ -187,6 +187,6 @@ private:
     bool videoEnabled;
 };
 
-};
+}; // namespace zbar
 
 #endif
